jacinle.utils.deprecated
========================

.. automodule:: jacinle.utils.deprecated

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      deprecated
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: deprecated


